<?php

// load libraries
require_once(__DIR__.'/../library/tonic/lib/tonic.php'); 
require_once(__DIR__.'/../library/utils/Errors.php');

// load adapters
require_once(__DIR__."/../adapters/ExpressoAdapter.php");
require_once(__DIR__."/../adapters/MailAdapter.php");
require_once(__DIR__."/../adapters/CatalogAdapter.php");

// Load all resources
require_once(__DIR__."/core/ExpressoVersionResource.php");
require_once(__DIR__."/core/LoginResource.php");
require_once(__DIR__."/core/LogoutResource.php");
require_once(__DIR__."/mail/FoldersResource.php");
require_once(__DIR__."/mail/MessagesResource.php");
require_once(__DIR__."/mail/AddFolderResource.php");
require_once(__DIR__."/mail/DelFolderResource.php");
require_once(__DIR__."/mail/RenameFolderResource.php");
require_once(__DIR__."/mail/CleanTrashResource.php");
require_once(__DIR__."/mail/AttachmentResource.php");
require_once(__DIR__."/mail/SendResource.php");
require_once(__DIR__."/mail/SendSupportFeedbackResource.php");
require_once(__DIR__."/catalog/ContactsResource.php");
require_once(__DIR__."/catalog/ContactPictureResource.php");

//Retrieveing the mapping of the URIs and his respectives classNames and classPath
$config = parse_ini_file( __DIR__ . '/../config/Tonic.srv', true );
$autoload = array();
$classpath = array();

foreach( $config as $uri => $classFile )
	foreach( $classFile as $className => $filePath )
	{
		$autoload[ $uri ] = $className;
		$classpath[ $className ] = $filePath;
	}

	$request = new Request(array(
			'baseUri' => dirname($_SERVER['SCRIPT_NAME']),
			'autoload' => $autoload
	));
	
try {
	$resource = $request->loadResource();
	$response = $resource->exec($request);
	
} catch (ResponseException $e) {
	
	switch ($e->getCode()) {
		
		case Response::UNAUTHORIZED:
			$response = $e->response($request);
			$response->addHeader('WWW-Authenticate', 'Basic realm="Tonic"');
			break;
		default:
			
			$response = new Response($request);
			$response->code = Response::OK;
			$response->addHeader('content-type', 'application/json');
			if($request->id)
				$body['id']	= $request->id;
			
			$body['error'] = array("code" => "".$e->getCode(), "message" => $e->getMessage());
			$response->body = json_encode($body);
	}
}

$response->output();

?>
